==> mutual_credit-5.0.12.tar.gz: mutual_credit/src/Form/MiscSettings.php <==
<?php

namespace Drupal\mcapi\Form;

use Drupal\mcapi\Mcapi;
use Drupal\mcapi\Entity\State;
use Drupal\views\Entity\View;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form builder for miscellaneous settings.
 */
class MiscSettings extends ConfigFormBase {

  private $moduleHandler;
  private $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mcapi_misc_settings';
  }

  /**
   * Constructor.
   *
   * @param ConfigFactoryInterface $configFactory
   *   The Configfactory service.
   * @param ModuleHandlerInterface $module_handler
   *   The ModuleHandler service.
   * @param EntityTypeManagerInterface $entity_type_manager
   *   The EntityTypeManager service.
   */
  public function __construct(ConfigFactoryInterface $configFactory, ModuleHandlerInterface $module_handler, EntityTypeManagerInterface $entity_type_manager) {
    $this->setConfigFactory($configFactory);
    $this->moduleHandler = $module_handler;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Injections.
   */
  static public function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('module_handler'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('mcapi.settings');
    $form['sentence_template'] = [
      '#title' => $this->t('Sentence view mode.'),
      '#description' => $this->t('The following tokens are available: @tokens', ['@tokens' => Mcapi::tokenHelp()]),
      '#type' => 'textfield',
      '#default_value' => $config->get('sentence_template'),
      '#weight' => 2,
    ];
    $form['worths_delimiter'] = [
      '#title' => $this->t('Delimiter'),
      '#description' => $this->t('What characters should be used to separate values when a transaction has multiple currencies?'),
      '#type' => 'textfield',
      '#default_value' => $config->get('worths_delimiter'),
      '#weight' => 12,
      '#size' => 10,
      '#maxlength' => 10,
    ];
    $form['zero_snippet'] = [
      '#title' => $this->t('Zero snippet'),
      '#description' => $this->t("string to replace '0:00' when the currency allows zero transactions"),
      '#type' => 'textfield',
      '#default_value' => $config->get('zero_snippet'),
      '#weight' => 13,
      '#size' => 20,
      '#maxlength' => 128,
    ];
    // @note Instead of this, 'counted' could be a property of each transaction
    // state however at the moment that would involve user 1 editing the yml
    // files because transaction states have no ui to edit them.
    $form['counted'] = [
      '#title' => $this->t('Counted transaction states'),
      '#description' => $this->t("Transactions in these states will comprise the wallet's balance"),
      '#type' => 'checkboxes',
      '#options' => Mcapi::entityOptions('mcapi_state'),
      '#default_value' => $config->get('counted'),
      '#weight' => 14,
      // These values are absolutely fixed.
      'done' => [
        '#disabled' => TRUE,
        '#value' => TRUE,
      ],
      'erased' => [
        '#disabled' => TRUE,
        '#value' => FALSE,
      ],
    ];

    if (\Drupal::entityQuery('mcapi_currency')->count()->execute() > 1) {
      $form['render_unused'] = [
        '#title' => $this->t('Show unused currencies.'),
        '#description' => $this->t('When displaying the wallet, do not show info about currencies not used.'),
        '#type' => 'checkbox',
        '#default_value' => $config->get('render_unused'),
        '#weight' => 15,
      ];
    }

    $form['user_transaction_view'] = [
      '#title' => $this->t("Transaction display"),
      '#description' => t('When looking at a wallet (or user).'),
      '#type' => 'radios',
      '#options' => [
        '' => $this->t('None'),
        'inex' => $this->t('Income & expenditure'),
        'statement' => $this->t('Statement', [], ['context' => 'like a bank statement']),
      ],
      '#default_value' => $config->get('user_transaction_view'),
      '#weight' => 17,
      '#disabled' => !$this->moduleHandler->moduleExists('views')
    ];

    $form['rebuild_mcapi_index'] = [
      '#title' => $this->t('Rebuild index'),
      '#description' => $this->t('The index table stores the transactions in an views-friendly format. It should never need rebuilding on a working system.'),
      '#type' => 'fieldset',
      '#weight' => 20,
      'button' => [
        '#type' => 'submit',
        '#value' => t('Rebuild transaction index'),
        '#submit' => [
          [get_class($this), 'rebuildMcapiIndex'],
        ],
      ],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $config = $this->config('mcapi.settings');

    $config
      ->set('sentence_template', $values['sentence_template'])
      ->set('zero_snippet', $values['zero_snippet'])
      ->set('worths_delimiter', $values['worths_delimiter'])
      ->set('render_unused', @$values['render_unused'])
      ->set('counted', $values['counted']);
    if ($this->moduleHandler->moduleExists('views')) {
      $config->set('user_transaction_view', $values['user_transaction_view']);
      $this->userTransactionView($values['user_transaction_view']);
    }

    $config->save();

    parent::submitForm($form, $form_state);
    if ($config->get('counted') != $values['counted']) {
      Self::rebuildMcapiIndex($form, $form_state);
    }

    Cache::invalidateTags(
      ['mcapi_wallet_values', 'mcapi_wallet_view']
    );
  }

  /**
   * Submit callback.
   *
   * Rebuild the Transaction index table.
   */
  public static function rebuildMcapiIndex(array &$form, FormStateInterface $form_state) {
    \Drupal::entityTypeManager()->getStorage('mcapi_transaction')->indexRebuild();
    \Drupal::messenger()->addStatus(t("Index table now tallies with transaction table."));
    $form_state->setRedirect('system.status');
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['mcapi.settings'];
  }

  private static function userTransactionView(string $display) {
    $inex = View::load('income_expenditure');
    $statement = View::load('wallet_transactions');
    if ($display == 'inex') {
      if (!$inex->status()) {
        $inex->setStatus(TRUE)->save();
        $statement->setStatus(FALSE)->save();
      }
    }
    elseif ($display == 'statement') {
      if (!$statement->status()) {
        $inex->setStatus(FALSE)->save();
        $statement->setStatus(TRUE)->save();
      }
    }
    else {
      if($statement->status()) {
        $statement->setStatus(FALSE)->save();
      }
      if($inex->status()) {
        $inex->setStatus(FALSE)->save();
      }
    }
  }

}

==> mutual_credit-5.1.0.tar.gz: mutual_credit/src/Form/MiscSettings.php <==
<?php

namespace Drupal\mcapi\Form;

use Drupal\mcapi\Mcapi;
use Drupal\mcapi\Entity\State;
use Drupal\views\Entity\View;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form builder for miscellaneous settings.
 */
class MiscSettings extends ConfigFormBase {

  private $moduleHandler;
  private $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mcapi_misc_settings';
  }

  /**
   * Constructor.
   *
   * @param ConfigFactoryInterface $configFactory
   *   The Configfactory service.
   * @param ModuleHandlerInterface $module_handler
   *   The ModuleHandler service.
   * @param EntityTypeManagerInterface $entity_type_manager
   *   The EntityTypeManager service.
   */
  public function __construct(ConfigFactoryInterface $configFactory, ModuleHandlerInterface $module_handler, EntityTypeManagerInterface $entity_type_manager) {
    $this->setConfigFactory($configFactory);
    $this->moduleHandler = $module_handler;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Injections.
   */
  static public function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('module_handler'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('mcapi.settings');
    $form['sentence_template'] = [
      '#title' => $this->t('Sentence view mode.'),
      '#description' => $this->t('The following tokens are available: @tokens', ['@tokens' => Mcapi::tokenHelp()]),
      '#type' => 'textfield',
      '#default_value' => $config->get('sentence_template'),
      '#weight' => 2,
    ];
    $form['worths_delimiter'] = [
      '#title' => $this->t('Delimiter'),
      '#description' => $this->t('What characters should be used to separate values when a transaction has multiple currencies?'),
      '#type' => 'textfield',
      '#default_value' => $config->get('worths_delimiter'),
      '#weight' => 12,
      '#size' => 10,
      '#maxlength' => 10,
    ];
    $form['zero_snippet'] = [
      '#title' => $this->t('Zero snippet'),
      '#description' => $this->t("string to replace '0:00' when the currency allows zero transactions"),
      '#type' => 'textfield',
      '#default_value' => $config->get('zero_snippet'),
      '#weight' => 13,
      '#size' => 20,
      '#maxlength' => 128,
    ];

    if (\Drupal::entityQuery('mcapi_currency')->count()->execute() > 1) {
      $form['render_unused'] = [
        '#title' => $this->t('Show unused currencies.'),
        '#description' => $this->t('When displaying the wallet, do not show info about currencies not used.'),
        '#type' => 'checkbox',
        '#default_value' => $config->get('render_unused'),
        '#weight' => 15,
      ];
    }

    $form['mail_all'] = [
      '#title' => $this->t('Notify transactees', [], ['context' => 'The other party to the transaction.']),
      '#description' => $this->t('Email a user (not the current user) when a transaction involving them changes state.'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('mail_all'),
      '#weight' => 15,
    ];
    $form['mail_template'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Notification mail'),
      '#tree' => TRUE,
      'subject' => [
        '#title' => $this->t('Notification subject'),
        '#description' => $this->t('Use tokens'),
        '#type' => 'textfield',
        '#default_value' => $config->get('mail_template.subject'),
        '#weight' => 1,
      ],
      'body' => [
        '#title' => $this->t('Mail body'),
        '#description' => $this->t('Use tokens'),
        '#type' => 'textarea',
        '#weight' => 2,
        '#default_value' => $config->get('mail_template.body'),
        '#weight' => 2,
      ],
      '#weight' => 16,
      '#states' => [
        'visible' => [
          [':input[name="mail_all"]' => ['checked' => TRUE]]
        ]
      ]
    ];
    if (\Drupal::moduleHandler()->moduleExists('token')) {
      $form['mail_template']['tokens'] = [
        '#theme' => 'token_tree_link',
        '#token_types' => ['user', 'xaction', 'site', 'current-user'],
        '#global_types' => FALSE,
        '#weight' => 3,
      ];
    }

    if ($this->moduleHandler->moduleExists('views')) {
      $form['user_transaction_view'] = [
        '#title' => $this->t("Transaction display"),
        '#description' => $this->t('When looking at a wallet (or user).'),
        '#type' => 'radios',
        '#options' => [
          '' => $this->t('None'),
          'income_expenditure' => $this->t('Income & expenditure'),
          'wallet_transaction' => $this->t('Statement', [], ['context' => 'like a bank statement']),
        ],
        '#default_value' => $config->get('user_transaction_view'),
        '#weight' => 17,
        '#disabled' => !$this->moduleHandler->moduleExists('views')
      ];
    }

    $form['rebuild_mcapi_index'] = [
      '#title' => $this->t('Rebuild index'),
      '#description' => $this->t('The index table stores the transactions in an views-friendly format. It should never need rebuilding on a working system.'),
      '#type' => 'fieldset',
      '#weight' => 20,
      'button' => [
        '#type' => 'submit',
        '#value' => $this->t('Rebuild transaction index'),
        '#submit' => [
          [get_class($this), 'rebuildMcapiIndex'],
        ],
      ],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $config = $this->config('mcapi.settings');

    $config
      ->set('sentence_template', $values['sentence_template'])
      ->set('zero_snippet', $values['zero_snippet'])
      ->set('worths_delimiter', $values['worths_delimiter'])
      ->set('mail_all', (bool)$values['mail_all'])
      ->set('mail_template', $values['mail_template']);
    if (isset($values['render_unused'])) {
      $config->set('render_unused', (bool)$values['render_unused']);
    }

    if ($this->moduleHandler->moduleExists('views')) {
      $config->set('user_transaction_view', $values['user_transaction_view']);
      $this->userTransactionView($values['user_transaction_view']);
    }

    $config->save();

    parent::submitForm($form, $form_state);

    Cache::invalidateTags(
      ['mcapi_wallet_values', 'mcapi_wallet_view']
    );
  }

  /**
   * Submit callback.
   *
   * Rebuild the Transaction index table.
   */
  public static function rebuildMcapiIndex(array &$form, FormStateInterface $form_state) {
    \Drupal::entityTypeManager()->getStorage('mcapi_transaction')->indexRebuild();
    \Drupal::messenger()->addStatus($this->t("Index table now tallies with transaction table."));
    $form_state->setRedirect('system.status');
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['mcapi.settings'];
  }

  private static function userTransactionView(string $view_name) {
    $inex = View::load('income_expenditure');
    $statement = View::load('wallet_transactions');
    $statement->setStatus(FALSE);
    $inex->setStatus(FALSE);
    if ($view_name == 'income_expenditure') {
      $inex->setStatus(TRUE);
    }
    elseif ($view_name == 'wallet_transactions') {
      $inex->setStatus(FALSE);
    }
    $inex->save();
    $statement->save();
  }

}
